@@ -24,4 +24,4 @@
 #' @useDynLib Rlibeemd
 #' @import Rcpp
 #' @importFrom stats time tsp "tsp<-"
-NULL
+"_PACKAGE"
